==> react-codemirror-merge-4.19.14.tgz: package/esm/Original.js <==
import _extends from "@babel/runtime/helpers/extends";
import { useEffect } from 'react';
import { StateEffect } from '@codemirror/state';
import { useStore } from './store';
import { getDefaultExtensions } from '@uiw/react-codemirror';
export var Original = props => {
  var {
    extensions = []
  } = props;
  var {
    original,
    view,
    dispatch
  } = useStore();
  var defaultExtensions = getDefaultExtensions();
  useEffect(() => {
    var data = {
      extensions: [...defaultExtensions, ...extensions]
    };
    if ((original == null ? void 0 : original.doc) !== props.value && view) {
      data.doc = props.value;
      dispatch({
        original: _extends({}, original, data)
      });
      var originalDoc = view == null ? void 0 : view.a.state.doc.toString();
      if (originalDoc !== props.value) {
        view == null ? void 0 : view.a.dispatch({
          changes: {
            from: 0,
            to: (originalDoc || '').length,
            insert: props.value || ''
          }
        });
      }
    }
    if ((original == null ? void 0 : original.selection) !== props.selection) {
      data.selection = props.selection;
      dispatch({
        original: _extends({}, original, data)
      });
    }
  }, [props.value, props.selection, view]);
  useEffect(() => {
    if (view) {
      view.a.dispatch({
        effects: StateEffect.appendConfig.of([...defaultExtensions, ...extensions])
      });
    }
  }, [extensions, view]);
  return null;
};
Original.displayName = 'CodeMirrorMerge.Original';

==> react-codemirror-merge-4.20.1.tgz: package/esm/Original.js <==
import _extends from "@babel/runtime/helpers/extends";
import { useEffect } from 'react';
import { StateEffect, Annotation } from '@codemirror/state';
import { EditorView } from '@codemirror/view';
import { getDefaultExtensions } from '@uiw/react-codemirror';
import { useStore } from './store';
var External = Annotation.define();
export var Original = props => {
  var {
    extensions = [],
    onChange
  } = props;
  var {
    original,
    view,
    dispatch
  } = useStore();
  var defaultExtensions = getDefaultExtensions();
  useEffect(() => {
    var updateListener = EditorView.updateListener.of(vu => {
      if (vu.docChanged && typeof onChange === 'function' &&
      // Fix echoing of the remote changes:
      // If transaction is market as remote we don't have to call `onChange` handler again
      !vu.transactions.some(tr => tr.annotation(External))) {
        var doc = vu.state.doc;
        var _value = doc.toString();
        onChange(_value, vu);
      }
    });
    var data = {
      extensions: [updateListener, ...defaultExtensions, ...extensions]
    };
    if ((original == null ? void 0 : original.doc) !== props.value && view) {
      data.doc = props.value;
      dispatch({
        original: _extends({}, original, data)
      });
      var originalDoc = view == null ? void 0 : view.a.state.doc.toString();
      if (originalDoc !== props.value) {
        view == null ? void 0 : view.a.dispatch({
          changes: {
            from: 0,
            to: (originalDoc || '').length,
            insert: props.value || ''
          },
          effects: StateEffect.appendConfig.of([...defaultExtensions, ...extensions])
        });
      }
    }
    if ((original == null ? void 0 : original.selection) !== props.selection) {
      data.selection = props.selection;
      dispatch({
        original: _extends({}, original, data)
      });
    }
  }, [props.value, props.selection, view]);
  return null;
};
Original.displayName = 'CodeMirrorMerge.Original';
